#!/usr/bin/env python
# -*- coding: utf-8 -*-

import numpy as np
import matplotlib as mpl
import matplotlib.pyplot as plt
import csv
from matplotlib.backends.backend_pdf import PdfPages
from mpl_toolkits.axes_grid1 import make_axes_locatable
from scipy.signal import savgol_filter

from matplotlib import rcParams

# Legend personalization
import matplotlib.patches as mpatches
import matplotlib.lines as mlines
import warnings

N_values = [50,100,150,200]
N_lables = ["50","100","150","200"]

CommRng_values = [0.05,0.1,0.15,0.2,0.25,0.3,0.35,0.4,0.45,0.5]
CommRng_lables = ["","0.1","","0.2","","0.3","","0.4","","0.5"]

rcParams['font.family'] = 'sans-serif'
rcParams['font.sans-serif'] = 'Myriad Pro'
rcParams['mathtext.fontset']= "cm"

rcParams['lines.markersize'] = 20

fig, ax = plt.subplots(1,1, figsize=(15,10))

for j, N in enumerate(N_values):
	MEAN_COMM_LINKS=[]
	for i, CommRng in enumerate(CommRng_values):
		comm_links=np.load("raw_data/comm_links_commrng"+str(CommRng)+"_N"+str(N)+".npy")
		MEAN_COMM_LINKS.append(np.mean(comm_links))

	if(N==50):
		color='0.6'
		marker='o'
		# linestyle=(0, (3, 1, 1, 1, 1, 1))
		linestyle='-'
	if(N==100):
		color='0.4'
		marker='v'
		linestyle='-'
	if(N==150):
		color='0.2'
		marker='d'
		linestyle='-'
	if(N==200):
		color='0'
		marker='s'
		linestyle='-'

	plt.plot(CommRng_values,MEAN_COMM_LINKS,c=color,marker=marker,linewidth=6,linestyle=linestyle,label="$S=$"+str(N))

plt.legend(loc='upper left',edgecolor='black',fontsize=54,frameon=True, shadow=False, fancybox=True,handlelength=2,facecolor='white',framealpha=1.0)


plt.xlim(0.04,0.51)
plt.ylim(-10,170)

ax.set_xticks(CommRng_values)
ax.set_xticklabels(CommRng_lables,fontsize=48)
# ax.set_xlabel(r'$\mathrm{r_s}$',fontsize=96,fontweight='bold')
ax.set_xlabel("$r_s$",fontsize=96,fontweight='bold')

ax.set_yticks([0,20,40,60,80,100,120,140,160])
ax.set_yticklabels(["0","","40","","80","","120","","160"],fontsize=48)
# ax.set_ylabel(r'$\mathrm{<k>}$',fontsize=96,fontweight='bold'))
ax.set_ylabel("$<k>$",fontsize=96,fontweight='bold')


# ax.set_yticklabels(fontsize=34)

for axis in ['top','bottom','left','right']:
	ax.spines[axis].set_linewidth(3)

ax.tick_params('both', length=10, width=3, which='major')
ax.tick_params('both', length=10, width=1.5, which='minor')

plt.grid()

plt.tight_layout()
pp = PdfPages("Fig3_inset.pdf")
pp.savefig(bbox_inches='tight')
pp.close()